.. highlight:: shell

============
Installation
============

The Ballet framework is distributed as a Python package available on PyPI. The package includes

- the ballet CLI
- the ballet Python SDK
- the ballet feature engineering "plugin"
- the ballet project template and feature template

Stable release
--------------

To install ballet, run this command in your terminal:

.. code-block:: console

    $ pip install ballet

This is the preferred method to install ballet, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io/en/stable/
.. _Python installation guide: https://docs.python-guide.org/starting/installation/


From source
-----------

The source for ballet can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/ballet/ballet

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/ballet/ballet/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ make install


.. _Github repo: https://github.com/ballet/ballet
.. _tarball: https://github.com/ballet/ballet/tarball/master
